@@ -133,12 +133,6 @@ add_lab_cols <- function(data,
 \nNote: labelr is not optimized for data.frames this large.")
   }
 
-  # check systematically for all found values being NA
-  size <- 5000
-  if (nrow(data) < size) size <- nrow(data)
-  inds2check <- unique(floor(seq(1, nrow(data), length.out = size)))
-  any_all_na_init <- any(sapply(data[inds2check, ], function(x) all(is.na(x))))
-
   # get label attributes, to restore when we're done
   initial_lab_atts <- get_all_lab_atts(data)
 
@@ -206,20 +200,6 @@ No value labels found for supplied var --%s--.",
 
   # to restore label attributes information
   data <- add_lab_atts(data, initial_lab_atts, num.convert = FALSE)
-
-  # check systematically for columns that lost many values to NA
-  inds2check <- unique(floor(seq(1, nrow(data), length.out = size)))
-  any_all_na_end <- any(sapply(data[inds2check, ], function(x) all(is.na(x))))
-
-  # throw an error if some column acquired new NA values based on
-  # non-comprehensive but systematic test
-  if (!any_all_na_init && any_all_na_end) {
-    stop("
-\nThis application of add_lab_cols() would lead a column to be coerced to all NA values,
-which is not allowed. This may result from attempting multiple nested or redundant
-calls to add_lab_cols() and/or related functions.
-           ")
-  }
   return(data)
 }
 
