@@ -154,12 +154,12 @@ use_val_labs <- function(data, vars = NULL) {
 Note: labelr is not optimized for data.frames this large.")
   }
 
-  # check systematically for all found values being NA
-  size <- 5000
-  if (nrow(data) < size) size <- nrow(data)
-  inds2check <- unique(floor(seq(1, nrow(data), length.out = size)))
-  any_all_na_init <- any(sapply(data[inds2check, ], function(x) all(is.na(x))))
-
+  # # check systematically for all found values being NA
+  # size <- 5000
+  # if (nrow(data) < size) size <- nrow(data)
+  # inds2check <- unique(floor(seq(1, nrow(data), length.out = size)))
+  # any_all_na_init <- any(sapply(data[inds2check, ], function(x) all(is.na(x))))
+  #
   # get value labs
   val.labs <- get_val_labs(data)
 
@@ -231,20 +231,20 @@ No value labels found for supplied var --%s--.",
       attributes(data)[[val_lab_name]] <- NULL
     }
 
-    # check systematically for columns that lost many values to NA
-    inds2check <- unique(floor(seq(1, nrow(data), length.out = size)))
-    any_all_na_end <- any(sapply(data[inds2check, ], function(x) all(is.na(x))))
-
-    # throw an error if some column acquired new NA values based on
-    # non-comprehensive but systematic test
-    if (!any_all_na_init && any_all_na_end) {
-      stop("
-\nThis application of use_val_labs() would lead a column to be coerced to all NA values,
-which is not allowed. This may result from attempting multiple nested or redundant
-calls to use_val_labs() and/or related functions.
-           ")
-    }
-
+    #     # check systematically for columns that lost many values to NA
+    #     inds2check <- unique(floor(seq(1, nrow(data), length.out = size)))
+    #     any_all_na_end <- any(sapply(data[inds2check, ], function(x) all(is.na(x))))
+    #
+    #     # throw an error if some column acquired new NA values based on
+    #     # non-comprehensive but systematic test
+    #     if (!any_all_na_init && any_all_na_end) {
+    #       stop("
+    # \nThis application of use_val_labs() would lead a column to be coerced to all NA values,
+    # which is not allowed. This may result from attempting multiple nested or redundant
+    # calls to use_val_labs() and/or related functions.
+    #            ")
+    #     }
+    #
     data <- clean_data_atts(data)
   }
 
